Installation
============

Python Package Index
--------------------
FauxFactory is available in PYPI and can be installed using pip::

    $ pip install fauxfactory

From Source
-----------
You can install FauxFactory by downloading the latest version of the source
code::

    $ git clone git@github.com:omaciel/fauxfactory.git
    $ cd fauxfactory
    $ python setup.py build install
